> This python package will have a collection of structures, functions and tools for interacting with LLMs and Datasets.

## Project and PyPI Package 
- https://pypi.org/project/slowblood/
- https://github.com/kyledinh/slowblood
- https://huggingface.co/Slowblood

## Usage Examples

- TODO 

## Required Dependencies

```
pip install -qU git+https://github.com/huggingface/transformers.git
pip install -qU git+https://github.com/huggingface/peft.git
pip install -qU git+https://github.com/huggingface/accelerate.git
```


## Package Structs, Methods and Consts 

### Datasets 

- `TextDataset`
- `prepare_dataset_llama2()`
- `generate_from_dataset_llama2()`

### Model

- `BITS_AND_BYTES_CONFIG_4BIT`
- `load_peft_model_with_adapters()` 
- `print_trainable_parameters()`

### PDF Manipulation 

- `convert_pdf_to_images()`
- `extract_text_from_pdf()` 
- `extract_text_from_imgs()`

### Settings

- `BasicInferenceRequest`
- `ArtifactNames`
- `FineTuningSettings`

### Tokenizer

- `get_tokenizer_for_model()`
- `update_model_with_tokenizer()`


